|
2 | 2 |
|
3 | 3 | <html> |
4 | 4 | <head> |
5 | | - <meta charset="utf-8" /> |
6 | | - <link rel="stylesheet" href="../../Static/css/reveal.css" /> |
7 | | - <link |
8 | | - rel="stylesheet" |
9 | | - href="../../Static/css/theme/white.css" |
10 | | - /> |
11 | | - <link rel="stylesheet" href="../../Static/css/custom.css" /> |
12 | | - <link |
13 | | - rel="stylesheet" |
14 | | - href="../../Static/css/atom-one-light.css" |
15 | | - /> |
| 5 | + <meta charset="utf-8"/> |
| 6 | + <link rel="stylesheet" href="../../Static/css/reveal.css"/> |
| 7 | + <link rel="stylesheet" href="../../Static/css/theme/white.css"/> |
| 8 | + <link rel="stylesheet" href="../../Static/css/custom.css"/> |
| 9 | + <link rel="stylesheet" href="../../Static/css/atom-one-light.css"/> |
16 | 10 | <script src="../../node_modules/reveal.js/dist/reveal.js" defer></script> |
17 | 11 | <script src="../../node_modules/reveal.js/dist/plugin/markdown.js" defer></script> |
18 | 12 | <script src="../../node_modules/reveal.js/dist/plugin/highlight.js" defer></script> |
|
227 | 221 | </div> |
228 | 222 | <div class="container"> |
229 | 223 | <div class="col"> |
230 | | - <pre><code data-noescape> |
| 224 | + <pre><code data-noescape class="language-cpp"> |
231 | 225 | q.parallel_for([=](sycl::item<1> it) { |
232 | 226 | sycl::atomic_ref<T, |
233 | 227 | sycl::memory_order_relaxed, |
|
288 | 282 | </div> |
289 | 283 | <div class="container"> |
290 | 284 | <div class="col"> |
291 | | - <pre><code data-noescape> |
| 285 | + <pre><code data-noescape class="language-cpp"> |
292 | 286 | q.submit([&](sycl::handler &cgh) { |
293 | 287 | // Output of reduction will be in ptr |
294 | 288 | auto sumReduction = sycl::reduction(ptr, |
|
315 | 309 | </div> |
316 | 310 | <div class="container"> |
317 | 311 | <div class="col"> |
318 | | - <pre><code data-noescape> |
| 312 | + <pre><code data-noescape class="language-cpp"> |
319 | 313 | q.submit([&](sycl::handler &cgh) { |
320 | 314 | // Output of reduction will be in ptr |
321 | 315 | auto maxReduction = sycl::reduction(ptr, |
|
0 commit comments